#include "Arduino.h"
#include "MiniLab.h"

namespace MiniLabSpace {


Color::Color (float r, float g, float b, float a) {

   this->r=r; this->g=g; this->b=b; this->a=a;
}

Color red(1,0,0, 1);
Color green(0,1,0, 1);
Color blue(0,0,1, 1);
Color yellow(1,1,0, 1);
Color cyan(0,1,1, 1);
Color magenta(1,0,1, 1);
Color white(1,1,1, 1);
Color black(0,0,0, 1);
Color gray(0.5,0.5,0.5, 1);


float _MiniLab::readFloat () {

   float f=Serial.parseFloat(); Serial.read(); Serial.read();
   return f;
}
int _MiniLab::readInt () {

   int i=Serial.parseInt(); Serial.read(); Serial.read();
   return i;
}
String _MiniLab::readString () {

   String str=Serial.readStringUntil('\r'); Serial.read();
   return str;
}

bool _MiniLab::checkTitle (String title) {

   String scene=readString();
   if(scene!=title) {             

      Serial.println(msg_titleError);    
      Serial.println(title);              
      return false;
   }             
   return true;
}

void _MiniLab::log (String str) {
   
   Serial.println(msg_log);
   Serial.println(str); 
}

void _MiniLab::beepSound () {
   
   Serial.println(msg_beepSound);
}
void _MiniLab::asteriskSound () {
   
   Serial.println(msg_asteriskSound);
}
void _MiniLab::exclamationSound () {
   
   Serial.println(msg_exclamationSound);
}
void _MiniLab::questionSound () {
   
   Serial.println(msg_questionSound);
}
void _MiniLab::handSound () {
   
   Serial.println(msg_handSound);
}

_MiniLab MiniLab; 


Control::Control (int i) {

   id=i;
}

void Control::enable () {

   Serial.println(id);
   Serial.println(work_enable); 
}
void Control::disable () {

   Serial.println(id);
   Serial.println(work_disable); 
}
void Control::setFront () {

   Serial.println(id);
   Serial.println(work_setFront); 
}
void Control::setRear () {

   Serial.println(id);
   Serial.println(work_setRear); 
}

void Control::setControl (int work, float f1, float f2, float f3, float f4) {

   Serial.println(id);
   Serial.println(work); 
   Serial.println(f1);
   Serial.println(f2);
   Serial.println(f3);
   Serial.println(f4);
}
void Control::setControl (int work, float f1, float f2, float f3) {

   Serial.println(id);
   Serial.println(work);    
   Serial.println(f1);
   Serial.println(f2);
   Serial.println(f3);
}
void Control::setControl (int work, String str) {

   Serial.println(id);
   Serial.println(work);    
   Serial.println(str);
}
void Control::setControl (int work, bool on) {

   Serial.println(id);
   Serial.println(work);    
   Serial.println(on);
}
void Control::setControl (int work, float f) {

   Serial.println(id);
   Serial.println(work);    
   Serial.println(f);
}
void Control::setControl (int work, double d) {

   Serial.println(id);
   Serial.println(work);    
   Serial.println(d);
}
void Control::setControl (int work, int i) {

   Serial.println(id);
   Serial.println(work);    
   Serial.println(i);
}

void TextControl::print (String str) {

   setControl(work_print, str);
}
void TextControl::print (float f) {

   setControl(work_print, f);
}
void TextControl::print (double d) {

   setControl(work_print, d);
}
void TextControl::print (int i) {

   setControl(work_print, i);
}

void TextLamp::set (Color color) {

   setControl(work_set, color.r, color.g, color.b, color.a);
}

void Check::set (bool on) {

   setControl(work_set, on);
}

void Bar::set (float value) {

   setControl(work_set, value);
}

void SlideBar::set (float minValue, float maxValue, float value) {

   setControl(work_set, minValue, maxValue, value);
}

void Selector::set (int i0_) {

   setControl(work_set, i0_);
}


}